
# Tools

Python tool with helper functions for setting up new pipeline and preparing reference data

[![Lint and Test](https://github.com/hydra-genetics/tools/actions/workflows/main.yaml/badge.svg?branch=master)](https://github.com/hydra-genetics/tools/actions/workflows/main.yaml)

![python](https://img.shields.io/badge/python-3.8-blue)

## Functions

* create
* reference


Example of how to generate a new project
```
 hydra-genetics create -n misc -d "Module containing rules that are general and most likely will be used by  multiple modules." -a "Patrik Smeds" -e patrik.smeds@scilifelab.uu.se -g Smeds -o misc
```
